Module mpmc

Module mpmc 

DPDK-style bounded MPMC ring queue

Structs

Consumer
Producer
ReadBatch
ReadGuard
WriteBatch
WriteGuard

Functions

minimum_file_size
Calculates the minimum file size required for a queue with given capacity. Note that file size MAY need to be increased beyond this to account for page-size requirements.
minimum_region_size
Calculates the minimum region size required for a queue with given capacity.
pair
Creates a new in-process MPMC queue pair backed by a heap allocation.